@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_NAMESPACEJOB_H
-#define KIMAP_NAMESPACEJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -13,7 +12,6 @@
 
 namespace KIMAP
 {
-
 class Session;
 struct Response;
 struct MailBoxDescriptor;
@@ -42,5 +40,3 @@ protected:
 };
 
 }
-
-#endif
